@@ -1,9 +1,9 @@
 /* $Id$
 
-   Copyright (C) 2023 Aamot Broadcast
+   Copyright (C) 2020-2022 Aamot Software
    Author(s): Ole Aamot <ole@gnome.org>
    License: GNU GPL version 3
-   Version: 0.4.0 (203-08-07))
+   Version: 6.2.0 (2022-07-09))
    Website: http://www.garagejam.org/
 
  */
@@ -19,6 +19,10 @@
 #include <champlain/champlain.h>
 #include <champlain-gtk/champlain-gtk.h>
 #include <string.h>
+#include <glib.h>
+#include <sys/socket.h>
+#include <netdb.h>
+#include <arpa/inet.h>
 #include "garagejam.h"
 #include "garagejam-gingerblue-chord.h"
 #include "garagejam-gingerblue-config.h"
@@ -65,6 +69,8 @@ GstPlayer *player;
 
 GstTagList *tag_list;
 
+gchar xspfbuffer[8192];
+
 GError *error = NULL;
 
 static void gb_assistant_entry_changed(GtkEditable * editable,
@@ -154,6 +160,9 @@ static void gb_assistant_cancel(GtkAssistant * assistant, gpointer data)
 static void gb_assistant_close(GtkAssistant * assistant, gpointer data)
 {
 	FILE *fp = NULL;
+	FILE *file = NULL;
+
+	long file_size;
 	GDateTime *datestamp = g_date_time_new_now_utc ();
 	gchar *filename =
 	    g_strconcat(g_get_user_special_dir(G_USER_DIRECTORY_MUSIC), "/",
@@ -185,6 +194,7 @@ static void gb_assistant_close(GtkAssistant * assistant, gpointer data)
 	fprintf(fp, "</gingerblue>\n");
 	fclose(fp);
 	g_date_time_unref (datestamp);
+	main_studio_stream(filename, gtk_entry_get_text(GTK_ENTRY(studio_entry))); 
 	gst_element_send_event(data, gst_event_new_eos());
 }
 
@@ -192,13 +202,15 @@ static void gb_assistant_apply(GtkAssistant * assistant, gpointer data)
 {
         GingerblueData *garagejam_config;
         GtkWindow *garagejam_window;
-        /* gtk_init (&argc, &argv); */
+        FILE *file;
+	/* gtk_init (&argc, &argv); */
         garagejam_config = main_config (GTK_WIDGET(garagejam_window), gtk_entry_get_text(GTK_ENTRY(studio_entry)));
         garagejam_window = garagejam_main_loop (garagejam_config);
         gtk_widget_show_all (garagejam_window);
         /* gst_init(&argc, &argc); */
         /* gtk_main(); */
 	gst_element_send_event(data, gst_event_new_eos());
+	return;
 }
 
 GtkAssistantPageFunc gb_assistant_cb(GtkAssistant * assistant,
@@ -209,6 +221,7 @@ GtkAssistantPageFunc gb_assistant_cb(GtkAssistant * assistant,
 
 int main(int argc, char **argv)
 {
+        GSocketConnectable *addr;
 	GDateTime *datestamp;
 	GingerblueData *data;
 	GingerblueChord *garagejam_chord;
@@ -260,6 +273,7 @@ int main(int argc, char **argv)
 				      g_date_time_format_iso8601 (datestamp), "]",
 				      ".ogg", NULL);
 	gtk_init(&argc, &argv);
+	gst_init(&argc, &argc);	
 	window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
 	introduction = gtk_assistant_new();
 	gtk_widget_set_size_request(GTK_WIDGET(introduction), 640, 480);
@@ -311,6 +325,9 @@ int main(int argc, char **argv)
 	computer_label = gtk_label_new(_("Computer:"));
 	computer_entry = gtk_entry_new();
 	gtk_entry_set_text(GTK_ENTRY(computer_entry), _(g_get_host_name()));
+	addr = g_network_address_new (_(g_get_host_name()), 12348);
+	gtk_entry_set_text(GTK_ENTRY(computer_entry), 
+			   g_network_address_get_hostname(addr));
 	gtk_box_pack_start(GTK_BOX(page[6].widget), GTK_WIDGET(computer_label),
 			   FALSE, FALSE, 5);
 	gtk_box_pack_start(GTK_BOX(page[6].widget), GTK_WIDGET(computer_entry),
@@ -339,7 +356,7 @@ int main(int argc, char **argv)
 			   FALSE, FALSE, 5);
 	studio_label = gtk_button_new_with_label("Broadcasting");
 	studio_entry = gtk_entry_new();
-	gtk_entry_set_text(GTK_ENTRY(studio_entry), g_strconcat("https://api.gingerblue.org/", gtk_entry_get_text(GTK_ENTRY(label_entry)), "/", gtk_entry_get_text(GTK_ENTRY(computer_entry)), NULL));
+	gtk_entry_set_text(GTK_ENTRY(studio_entry), g_strconcat("https://www.gingerblue.org/api/", gtk_entry_get_text(GTK_ENTRY(label_entry)), "/", gtk_entry_get_text(GTK_ENTRY(computer_entry)), NULL));
 	g_signal_connect(G_OBJECT(studio_label), "clicked",
 			 G_CALLBACK(gb_assistant_apply),
 		         gtk_entry_get_text(GTK_ENTRY(studio_entry)));
@@ -378,7 +395,7 @@ int main(int argc, char **argv)
 		         gtk_entry_get_text(GTK_ENTRY(stream_entry)));
 	gchar *record_attachment = g_strconcat(gtk_entry_get_text(GTK_ENTRY(recording_entry)), NULL);
 	gchar *subject = g_strconcat(gtk_entry_get_text(GTK_ENTRY(label_entry)), "/", gtk_entry_get_text(GTK_ENTRY(computer_entry)), NULL);
-	page[10].widget = gtk_link_button_new_with_label (g_strconcat("https://api.gingerblue.org/", subject, NULL), "Connect GarageJam to Gingerblue Recording Studio API");
+	page[10].widget = gtk_link_button_new_with_label (g_strconcat("https://www.gingerblue.org/api/", subject, NULL), "Connect GarageJam to Gingerblue Recording Studio API");
 	gtk_entry_set_text(GTK_ENTRY(page[10].widget), "Click Apply");
 	g_signal_connect (GTK_BUTTON(stream_entry), "clicked", G_CALLBACK(gb_assistant_apply), gtk_entry_get_text(GTK_ENTRY(studio_entry)));
 	g_signal_connect(G_OBJECT(stream_label), "clicked",
@@ -487,25 +504,8 @@ int main(int argc, char **argv)
 	gst_element_set_state(pipeline, GST_STATE_PLAYING);
 
 	xspf = fopen(g_strconcat(g_get_user_special_dir(G_USER_DIRECTORY_MUSIC), "/", gtk_entry_get_text(GTK_ENTRY(label_entry)), ".xspf", NULL), "w+");
-	fprintf(xspf, "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n");
-	fprintf(xspf, "<playlist version=\"1\" xmlns=\"http://xspf.org/ns/0/\">\n");
-	fprintf(xspf, "<trackList>\n");
-	fprintf(xspf, "<track>\n");
-	fprintf(xspf, "%s", g_strconcat("<title>", gtk_entry_get_text(GTK_ENTRY(song_entry)), "</title>\n", NULL));
-	fprintf(xspf, "%s", g_strconcat("<location>file://", gtk_entry_get_text(GTK_ENTRY(computer_entry)), "/", gtk_entry_get_text(GTK_ENTRY(recording_entry)), "</location>\n", NULL));
-	fprintf(xspf, "<meta rel='http://api.gingerblue.org/%s/version'>%s</meta>\n", gtk_entry_get_text(GTK_ENTRY(label_entry)), VERSION);
-	fprintf(xspf, "<meta rel='http://api.gingerblue.org/%s/musician'>%s</meta>\n", gtk_entry_get_text(GTK_ENTRY(label_entry)), gtk_entry_get_text(GTK_ENTRY(musician_entry)));
-	fprintf(xspf, "<meta rel='http://api.gingerblue.org/%s/song'>%s</meta>\n", gtk_entry_get_text(GTK_ENTRY(label_entry)), gtk_entry_get_text(GTK_ENTRY(song_entry)));
-	fprintf(xspf, "<meta rel='http://api.gingerblue.org/%s/instrument'>%s</meta>\n", gtk_entry_get_text(GTK_ENTRY(label_entry)), gtk_entry_get_text(GTK_ENTRY(instrument_entry)));
-	fprintf(xspf, "<meta rel='http://api.gingerblue.org/%s/line'>%s</meta>\n", gtk_entry_get_text(GTK_ENTRY(label_entry)), gtk_entry_get_text(GTK_ENTRY(line_entry)));
-	fprintf(xspf, "<meta rel='http://api.gingerblue.org/%s/label'>%s</meta>\n", gtk_entry_get_text(GTK_ENTRY(label_entry)), gtk_entry_get_text(GTK_ENTRY(label_entry)));
-	fprintf(xspf, "<meta rel='http://api.gingerblue.org/%s/station'>%s</meta>\n", gtk_entry_get_text(GTK_ENTRY(label_entry)), gtk_entry_get_text(GTK_ENTRY(computer_entry)));
-	fprintf(xspf, "<meta rel='http://api.gingerblue.org/%s/filename'>%s</meta>\n", gtk_entry_get_text(GTK_ENTRY(label_entry)), gtk_entry_get_text(GTK_ENTRY(recording_entry)));
-	fprintf(xspf, "<meta rel='http://api.gingerblue.org/%s/album'>%s</meta>\n", gtk_entry_get_text(GTK_ENTRY(label_entry)), gtk_entry_get_text(GTK_ENTRY(album_entry)));
-	fprintf(xspf, "<meta rel='http://api.gingerblue.org/%s/studio'>%s</meta>\n", gtk_entry_get_text(GTK_ENTRY(label_entry)), gtk_entry_get_text(GTK_ENTRY(studio_entry)));
-	fprintf(xspf, "</track>\n");
-	fprintf(xspf, "</trackList>\n");
-	fprintf(xspf, "</playlist>\n");
+	sprintf(xspfbuffer, "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<playlist version=\"1\" xmlns=\"http://xspf.org/ns/0/\">\n<trackList>\n<track>\n<title>%s</title>\n<location>file://%s</location>\n</track>\n</trackList>\n</playlist>\n", gtk_entry_get_text(GTK_ENTRY(song_entry)), gtk_entry_get_text(GTK_ENTRY(recording_entry)));
+	fprintf(xspf, "%s", xspfbuffer);
 	fclose(xspf);
 
 	gtk_widget_set_size_request(GTK_WIDGET(window), 800, 600);
